EasyExtend.langlets.p4d.bytelet.Flow

Package EasyExtend :: Package langlets :: Package p4d :: Module bytelet :: Class Flow |
[hide private]
[frames] | no frames]

# Class Flow

    object --+
             |
            Flow

Known Subclasses:
  - FlowFieldVal
  - , FlowLen

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
flow_value(self) |
set_flow_value(self, val) |
set_node(self, node, parent=None) |
__getitem__(self, name) |
__copy__(self) |
__add__(self, item) |
__radd__(self, item) |
__sub__(self, item) |
__rsub__(self, item) |
__mul__(self, item) |
__rmul__(self, item) |
__div__(self, item) |
__rdiv__(self, item) |
compute(self, n) |
update(self) |
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)